
import java.text.DecimalFormat;
import java.sql.*;
import java.text.NumberFormat;

import ru.bitel.common.Utils;
import bitel.billing.server.reports.BGDataSource;
import bitel.billing.common.TimeUtils;

public void fillReport( con, filter, bitel.billing.server.reports.BGCSVReport.ReportResult result )
{
	java.sql.Date date1 = TimeUtils.convertDateToSqlDate( TimeUtils.parseDate( filter.getStringParam( "date1" ), "dd.MM.yyyy" ) );
	java.sql.Date date2 = TimeUtils.convertDateToSqlDate( TimeUtils.parseDate( filter.getStringParam( "date2" ), "dd.MM.yyyy" ) );
	
	String types = filter.getStringParam( "paymentTypes" );
	long groupMask = filter.getLongParam( "gr" );
	String mask = filter.getStringParam( "mask" );
	String groupMode = filter.getStringParam( "andOr" );            
    String users = filter.getStringParam( "users" );
    
    ArrayList data = new ArrayList( 1000 );
    
	NumberFormat format = DecimalFormat.getInstance();
	format.setMaximumFractionDigits(2);
	format.setGroupingUsed( false );
    
    if ( date1 != null && date2 != null && types != null )
	{		
		String query = "SELECT gr.title FROM contract_group gr WHERE ( 1 << gr.id ) & ? > 0";
		PreparedStatement getGroups = con.prepareStatement( query );
		
		query = "SELECT bcp.*, c.id AS cid, c.title AS contract_title, c.comment AS note, c.gr, user.name AS user, bpt.name AS paymentType FROM bonus_contract_payment AS bcp"
		+ " LEFT JOIN contract AS c ON bcp.cid=c.id"
		+ " LEFT JOIN user ON user.id=bcp.uid"
		+ " LEFT JOIN bonus_payment_type AS bpt ON bpt.id=bcp.typeId"
		+ " WHERE ( DATE(bcp.date) >= ? OR ISNULL( ? ) ) AND ( DATE(bcp.date) <= ? OR ISNULL( ? ) ) ";
		
		if ( groupMask != 0 && groupMode != null )
		{
			if( groupMode.equals( "or" ) )
			{
				query += " AND c.gr & " + groupMask + " > 0 ";
			}
			else
			{
				query += " AND c.gr & " + groupMask + "=" + groupMask + " ";
			}
		}
		
		if ( Utils.notEmptyString( types ) )
		{
			query += "AND bcp.typeId IN ( " + types + " ) ";
		}
        
        if( Utils.notEmptyString( users ) )
        {
            query += "AND bcp.uid IN ( " + users + " ) ";                    
        }
		
		PreparedStatement ps = con.prepareStatement( query );
		ps.setDate( 1, date1 );
		ps.setDate( 2, date1 );
		ps.setDate( 3, date2 );
		ps.setDate( 4, date2 );
		
//		System.out.println( query );
		ResultSet rs = ps.executeQuery();
		
		double totalSum = 0;
		while( rs. next() )
		{
			long gr = rs.getLong( "gr" );
			
			groups = "";
			
			getGroups.setLong( 1, gr );
			groupRS = getGroups.executeQuery();
			while( groupRS .next() )
			{		
				if( groups != "")
				{
					groups = groupRS.getString(1) + ", " + groups; 
				}
				else
				{
					groups = groupRS.getString(1);
				}
			}
			
			user = rs.getString( "user" );
			if ( Utils.isBlankString( user ) )
			{
				user = "Сервер";
			}
			summa = rs.getDouble( "sum" );
			
			map = new HashMap();
			map.put( "contract_title", rs.getString( "contract_title" ) );
			map.put( "note", rs.getString( "note" ) );
			map.put( "user", user );
			map.put( "summa", format.format( summa ) );
			map.put( "date", rs.getString( "date" ) );
			map.put( "period", TimeUtils.formatPeriod( rs.getTimestamp("dateFrom"), rs.getTimestamp("dateTo") ) ); 
			map.put( "payment_type", rs.getString( "paymentType" ) );
			map.put( "comment", rs.getString( "comment" ) );
			map.put( "group", groups );
			map.put( "#cid", rs.getString( "cid" ) );

			totalSum += summa;
			
			data.add( map );
		}
		
		if( data.size() > 1 )
		{
			map = new HashMap();
			map.put( "summa", format.format( totalSum ) );
			data.add(map);
		}
    }
    
    result.setData( data );
}
